pub fn config_error_to_pyvalue_err(e: ConfigError) -> PyErrExpand description
Converts a config validation failure to a Python ValueError.
pub fn config_error_to_pyvalue_err(e: ConfigError) -> PyErrConverts a config validation failure to a Python ValueError.